import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const ManageQnA = data => {
  const form = data.form
  const records = data.records

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.forms.index')}
        >
          <i className='fas fa-arrow-left' />
          Back to Forms
        </InertiaLink>

        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.forms.records.create', form)}
        >
          <span>
            <i className='fas fa-plus' />
            Create Record
          </span>
        </InertiaLink>

        <InertiaLink
          className='btn btn-light'
          href={route('eventpal.forms.qna.moderate', form)}
        >
          <span>
            <i className='fas fa-check' />
            Moderate Questions
          </span>
        </InertiaLink>
        <InertiaLink
          className='btn btn-light'
          href={route('eventpal.forms.qna.facilitate', form)}
        >
          <span>
            <i className='fas fa-eye' />
            Facilitate Questions
          </span>
        </InertiaLink>
      </div>

      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>#</th>
              <th>Status</th>
              <th>To</th>
              <th>From</th>
              <th>Message</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {records.map(record => (
              <tr key={record.id}>
                <td>{record.id}</td>
                <td>
                  {record.status === 'waiting' ? (
                    <span className='badge badge-default'>Waiting</span>
                  ) : (
                    ''
                  )}
                  {record.status === 'accepted' ? (
                    <span className='badge badge-success'>Accepted</span>
                  ) : (
                    ''
                  )}
                  {record.status === 'rejected' ? (
                    <span className='badge badge-danger'>Rejected</span>
                  ) : (
                    ''
                  )}
                  {record.status === 'read' ? (
                    <span className='badge badge-info'>Read</span>
                  ) : (
                    ''
                  )}
                </td>
                <td>{record.speaker}</td>
                <td>
                  {record.registration.firstname} {record.registration.surname}
                </td>
                <td>{record.question}</td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.forms.records.edit', [form, record])}
                    title='Edit Record'
                  >
                    <span>
                      <i className='fas fa-pencil-alt fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button'
                    href={`/eventpal/forms/${form.id}/records/${record.id}`} // TODO: Update to form / add in modal
                    title='Delete Record'
                    method='delete'
                  >
                    <span>
                      <i className='far fa-trash-alt fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {records.length === 0 && (
              <tr>
                <td className='no-results' colSpan='6'>
                  No Records found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
ManageQnA.layout = page => (
  <Layout area='Forms - Manage' title='Q&A'>
    {page}
  </Layout>
)

export default ManageQnA
