import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import IpadLayout from '@/Shared/IpadLayout'

const ModerateQnA = data => {
  const form = data.form
  const records = data.records
  const speakers = data.speakers
  const selectedSpeaker = data.selectedSpeaker

  return (
    <div>
      {speakers && (
        <div className='table-panel tw-p-5'>
          <form id='question-filter' action='#' method='get'>
            <label htmlFor='speaker'>Filter</label>
            <select id='filter-select' name='speaker'>
              {Object.entries(speakers).map(([key, value]) => (
                <option
                  selected={selectedSpeaker === value}
                  key={value}
                  value={value}
                >
                  {value}
                </option>
              ))}
            </select>
            <input
              id='filter-select-submit'
              type='submit'
              className='btn-dark tw-p-3'
              value='Apply'
            />
          </form>
        </div>
      )}
      <div className='table-panel'>
        <div className='table-panel__table'>
          <table className='table table-striped'>
            <thead>
              <tr>
                <th>Question</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
              {records.map(record => (
                <tr key={record.id}>
                  <td>
                    <span className='tw-text-lg'>{record.question}</span>
                    <br />
                    <small>
                      From {record.registration.firstname}{' '}
                      {record.registration.surname}
                    </small>
                  </td>
                  <td>
                    <InertiaLink
                      className='btn-success'
                      href={route('eventpal.forms.qna.status', [form, record])}
                      title='Accept'
                      method='patch'
                      data={{ status: 'accepted' }}
                    >
                      <span>
                        <i className='fas fa-check fa-lg' />
                      </span>
                    </InertiaLink>

                    <InertiaLink
                      className='btn-danger tw-ml-3'
                      href={route('eventpal.forms.qna.status', [form, record])}
                      title='Reject'
                      method='patch'
                      data={{ status: 'rejected' }}
                    >
                      <span>
                        <i className='fas fa-times fa-lg' />
                      </span>
                    </InertiaLink>
                  </td>
                </tr>
              ))}
              {records.length === 0 && (
                <tr>
                  <td className='no-results' colSpan='5'>
                    No Records found
                  </td>
                </tr>
              )}
            </tbody>
          </table>
        </div>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
ModerateQnA.layout = page => (
  <IpadLayout area='Forms - Manage - Q&A' title='Moderate'>
    {page}
  </IpadLayout>
)

export default ModerateQnA
