import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const Quizzes = data => {
  const quiz = data.quizzes

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.quiz.create')}
        >
          <span>
            <i className='fas fa-plus' />
            Create quiz
          </span>
        </InertiaLink>
      </div>

      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>#</th>
              <th>Title</th>
              <th>Questions</th>
              <th>Answers</th>
              <th>Status</th>
              <th>Controls</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {quiz.map(quiz => (
              <tr key={quiz.id}>
                <td>{quiz.id}</td>
                <td>{quiz.title}</td>
                <td>{quiz.questions}</td>
                <td>{quiz.answers}</td>
                <td>
                  {quiz.active > 0 ? (
                    <span className='badge badge-success'>Active</span>
                  ) : (
                    <span className='badge badge-danger'>Inactive</span>
                  )}
                </td>
                <td>
                  {quiz.active > 0 ? (
                    <InertiaLink
                      className='action-button'
                      href={route('eventpal.quiz.activity.de-activate', quiz)}
                      title='End quiz'
                    >
                      <span>
                        <i className='fas fa-times-circle fa-lg' />
                      </span>
                    </InertiaLink>
                  ) : (
                    <InertiaLink
                      className='action-button'
                      href={route('eventpal.quiz.activity.activate', quiz)}
                      title='Start quiz'
                    >
                      <span>
                        <i className='fas fa-check fa-lg' />
                      </span>
                    </InertiaLink>
                  )}
                </td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.questions.index', quiz)}
                    title='View questions'
                  >
                    <span>
                      <i className='far fa-arrow-alt-circle-right fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button danger'
                    href={route('eventpal.quiz.destroy', quiz)}
                    title='Delete'
                    method='delete'
                  >
                    <span>
                      <i className='fas fa-trash-alt fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.edit', quiz)}
                    title='Edit'
                  >
                    <span>
                      <i className='fas fa-pencil-alt fa-lg' />
                    </span>
                  </InertiaLink>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.sync', quiz)}
                    title='Sync Responses'
                  >
                    <span>
                      <i className='fas fa-sync-alt fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {quiz.length === 0 && (
              <tr>
                <td className='no-results' colSpan='7'>
                  No quizzes found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
Quizzes.layout = page => <Layout title='Quizzes'>{page}</Layout>

export default Quizzes
