import React from 'react'
import PropTypes from 'prop-types'
import FlashMessages from '@/Shared/FlashMessages'

function renderPageTitle(pageTitle, pageArea) {
  if (typeof pageArea === 'string' && pageArea.length > 0) {
    return (
      <h1 className='page-title'>
        <span className='page-area'>{pageArea} - </span>
        {pageTitle}
      </h1>
    )
  }

  return <h1 className='page-title'>{pageTitle}</h1>
}

export default function Content({ children, pageArea, pageTitle }) {
  return (
    <div className='tw-flex tw-flex-col tw-flex-grow tw-px-12 tw-py-8'>
      <div className='tw-mb-3'>
        <div className='tw-w-full'>
          <FlashMessages />
        </div>
        <div className='tw-mb-2 tw-w-full tw-max-w-full md:tw-max-w-3xl'>
          {renderPageTitle(pageTitle, pageArea)}
        </div>
      </div>
      <div className='container'>
        <article>{children}</article>
      </div>
    </div>
  )
}

Content.propTypes = {
  children: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
  pageArea: PropTypes.string,
  pageTitle: PropTypes.string.isRequired,
}
