import React, { useState } from 'react'
import PropTypes from 'prop-types'
import Select from 'react-select'

export default function ReactSelect({
  label,
  name,
  helpText,
  className,
  onChange,
  options = [],
  selectedOptions = [],
  errors = [],
  isDisabled = false,
  isSearchable = false,
  isMultiple = false,
}) {
  const selectStyles = {
    option: (provided, state) => ({
      ...provided,
      backgroundColor: state.isFocused ? 'rgba(93, 198, 195, 0.1)' : 'white',
    }),
    container: provided => ({
      ...provided,
      borderWidth: '2px',
      borderColor: '#e9eff2',
    }),
    control: provided => ({
      ...provided,
      borderWidth: '0',
      boxShadow: 'none',
    }),
  }

  const [selected, setSelected] = useState(() => {
    if (selectedOptions.length === 0) {
      return []
    }

    return options.filter(option => {
      return selectedOptions.find(
        selectedOption => selectedOption === option.value,
      )
    })
  })

  function handleChange(selectedOptions) {
    setSelected(selectedOptions)
    onChange({
      target: {
        name: name,
        value: selectedOptions.map(selectedOption => {
          return selectedOption.value
        }),
      },
    })
  }

  return (
    <div className={`tw-w-full tw-mb-8 input-group ${className}`}>
      {label && <label htmlFor={name}>{label}</label>}
      <Select
        value={selected}
        options={options}
        name={name}
        isDisabled={isDisabled}
        isSearchable={isSearchable}
        isMulti={isMultiple}
        onChange={handleChange}
        styles={selectStyles}
        width='100%'
      />
      {errors && <div className='input-group__form-error'>{errors[0]}</div>}
      {helpText && <div className='input-group__help-text'>{helpText}</div>}
    </div>
  )
}

ReactSelect.propTypes = {
  className: PropTypes.string,
  errors: PropTypes.array,
  helpText: PropTypes.string,
  isDisabled: PropTypes.bool,
  isMultiple: PropTypes.bool,
  isSearchable: PropTypes.bool,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  options: PropTypes.array.isRequired,
  selectedOptions: PropTypes.array,
}
