<?php

namespace Drp\EventPalAdmin;

use Drp\NativeEventApp\Models\Event;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\ServiceProvider;
use Inertia\Inertia;

class EventPalAdminServiceProvider extends ServiceProvider
{
    /**
     * Bootstrap the application services.
     */
    public function boot(): void
    {
        $this->registerInertia();

        /*
         * Optional methods to load your package assets
         */
        $this->loadViewsFrom(__DIR__.'/../resources/views', 'eventpal-admin');
        $this->loadRoutesFrom(__DIR__.'/routes/web.php');
        $this->loadMigrationsFrom(__DIR__.'/../database/migrations');

        if (!$this->app->runningInConsole()) {
            return;
        }

        $this->publishes([
            __DIR__ . '/../config/eventpal-admin.php' => config_path('eventpal-admin.php'),
        ], 'config');

        $this->publishes([
            __DIR__. '/../resources/views/graphs' => resource_path('views/vendor/eventpal-admin'),
        ], 'views');
    }

    /**
     * Register the application services.
     */
    public function register(): void
    {
        // Automatically apply the package configuration
        $this->mergeConfigFrom(__DIR__ . '/../config/eventpal-admin.php', 'eventpal-admin');

        // Register the main class to use with the facade
        $this->app->singleton('eventpal-admin', function () {
            return new EventPalAdmin;
        });

        if (File::isDirectory(public_path('eventpal')) !== false || config('eventpal-admin.assets.ignore_symlink')) {
            return;
        }

        File::link(__DIR__ .'/../dist', public_path('eventpal'));
    }

    public function registerInertia(): void
    {
        Inertia::version(function () {
            return md5_file(public_path('mix-manifest.json'));
        });

        Inertia::setRootView('eventpal-admin::app');

        Inertia::share([
            'auth' => function () {
                return [
                    'user' => Auth::user() ? [
                        'id' => Auth::user()->id,
                        'name' => Auth::user()->name,
                        'email' => Auth::user()->email,
                    ] : null,
                ];
            },
            'baseEvent' => function () {
                $event = Event::first();

                if ($event === null) {
                    return null;
                }

                return [
                    'event' => [
                        'id' => $event->id,
                        'title' => $event->title,
                        'name' => $event->name,
                    ],
                ];
            },
            'flash' => function () {
                return [
                    'success' => Session::get('success'),
                    'error' => Session::get('error'),
                ];
            },
            'errors' => function () {
                return Session::get('errors') ? Session::get('errors')->getBag('default')->getMessages() : (object) [];
            },
        ]);
    }
}
