<?php

namespace Drp\EventPalAdmin\Http\Controllers\Quiz;

use Drp\EventPalAdmin\Http\Controllers\Controller;
use Drp\EventPalAdmin\Http\Requests\CreateQuiz;
use Drp\NativeEventApp\Models\Quiz;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Inertia\Inertia;
use Inertia\Response;

class QuizController extends Controller
{
    public function index(): Response
    {
        return Inertia::render('Quizzes/Index', [
            'quizzes' => Quiz::with('questions.answers')->orderBy('id', 'asc')->get()
                ->transform(function ($quiz) {
                    return [
                        'id' => $quiz->id,
                        'active' => $quiz->active,
                        'title' => $quiz->title,
                        'questions' => $quiz->questions()->count(),
                        'answers' => $quiz->questions->flatMap->answers->count(),
                    ];
                }),
        ]);
    }

    public function create(): Response
    {
        return Inertia::render('Quizzes/Create');
    }

    public function store(CreateQuiz $request): RedirectResponse
    {
        Quiz::create($request->all());

        return Redirect::route('eventpal.quiz.index')->with('success', 'Quiz created.');
    }

    public function edit(Quiz $quiz): Response
    {
        return Inertia::render('Quizzes/Edit', [
            'quiz' => [
                'id' => $quiz->id,
                'active' => $quiz->active,
                'title' => $quiz->title,
                'type' => $quiz->type,
                'questions' => $quiz->questions()->count(),
                'answers' => $quiz->questions->flatMap->answers->count(),
            ],
        ]);
    }

    public function update(CreateQuiz $request, Quiz $quiz): RedirectResponse
    {
        $quiz->update($request->all());

        return Redirect::route('eventpal.quiz.index')->with('success', 'Quiz updated.');
    }

    public function destroy(Quiz $quiz): RedirectResponse
    {
        $quiz->delete();

        return Redirect::back()->with('success', 'Quiz deleted.');
    }
}
